/* BEGIN_COMMON_COPYRIGHT_HEADER
 * (c)LGPL2+
 *
 * LXQt - a lightweight, Qt based, desktop toolset
 * https://lxqt.org
 *
 * Copyright: 2013 Razor team
 * Authors:
 *   Kuzma Shapran <kuzma.shapran@gmail.com>
 *
 * This program or library is free software; you can redistribute it
 * and/or modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General
 * Public License along with this library; if not, write to the
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * END_COMMON_COPYRIGHT_HEADER */

#include <LXQt/SingleApplication>

#include <QCommandLineParser>
#include <QMessageBox>
#include "main_window.h"

int main(int argc, char *argv[])
{
    LXQt::SingleApplication a(argc, argv);

    QCommandLineParser parser;
    parser.setApplicationDescription(QStringLiteral("LXQt Config Globalkeys "));
    const QString VERINFO = QStringLiteral(LXQT_GLOBALKEYS_VERSION
                                           "\nliblxqt   " LXQT_VERSION
                                           "\nQt        " QT_VERSION_STR);
    a.setApplicationVersion(VERINFO);
    parser.addVersionOption();
    parser.addHelpOption();
    parser.process(a);
    // Show message under wayland
    if (QGuiApplication::platformName() == QLatin1String("wayland"))
    {
        QMessageBox::warning(nullptr,
            QObject::tr("Platform Unsupported"),
            QObject::tr("LXQt globalkeys are currently unsupported under Wayland.\n\nGlobal shortcuts can be configured in the settings of the compositor instead."));
        return 0;
    }

    MainWindow w;
    a.setActivationWindow(&w);
    w.show();

    return a.exec();
}
